@@ -94,7 +94,9 @@ setGeneric("get_required_features", function(x, ...) standardGeneric("get_requir
 
 setGeneric("get_model_features", function(x, ...) standardGeneric("get_model_features"))
 
-##### Clustering methods -------------------------------------------------------
+
+
+# clustering methods -----------------------------------------------------------
 setGeneric("set_similarity_table", function(object, data, ...) standardGeneric("set_similarity_table"))
 
 setGeneric(".set_similarity_table", function(object, data, ...) standardGeneric(".set_similarity_table"))
@@ -118,7 +120,130 @@ setGeneric(".cluster_by_dynamic_cut", function(object, ...) standardGeneric(".cl
 setGeneric(".cluster_by_generic", function(object, ...) standardGeneric(".cluster_by_generic"))
 
 
-##### Methods to see and update labels of data in familiarCollection objects.
+
+# export methods ---------------------------------------------------------------
+# Additional methods are found in FamiliarCollectionExport.R
+setGeneric(".export_to_file", function(data, object, dir_path, ...) standardGeneric(".export_to_file"))
+
+setGeneric(".export", function(x, ...) standardGeneric(".export"))
+
+
+
+# conversion & loading ---------------------------------------------------------
+# Additional methods are documented in FamiliarObjectConversion.R
+setGeneric("load_familiar_object", function(object, ...) standardGeneric("load_familiar_object"))
+
+
+# utilities --------------------------------------------------------------------
+setGeneric("is_empty", function(x, ...) standardGeneric("is_empty"))
+
+setGeneric("get_outcome_name", function(x, ...) standardGeneric("get_outcome_name"))
+
+setGeneric("get_outcome_class_levels", function(x, ...) standardGeneric("get_outcome_class_levels"))
+
+setGeneric("get_outcome_columns", function(x, ...) standardGeneric("get_outcome_columns"))
+
+setGeneric("get_non_feature_columns", function(x, ...) standardGeneric("get_non_feature_columns"))
+
+setGeneric("get_feature_columns", function(x, ...) standardGeneric("get_feature_columns"))
+
+setGeneric("get_n_features", function(x, ...) standardGeneric("get_n_features"))
+
+setGeneric("get_n_samples", function(x, ...) standardGeneric("get_n_samples"))
+
+setGeneric("has_feature_data", function(x, ...) standardGeneric("has_feature_data"))
+
+setGeneric("get_unique_row_names", function(x, ...) standardGeneric("get_unique_row_names"))
+
+setGeneric("get_class_probability_name", function(x, ...) standardGeneric("get_class_probability_name"))
+
+setGeneric("encode_categorical_variables", function(object, data, ...) standardGeneric("encode_categorical_variables"))
+
+setGeneric("get_placeholder_prediction_table", function(object, data, ...) standardGeneric("get_placeholder_prediction_table"))
+
+setGeneric("has_bad_training_data", function(object, data, ...) standardGeneric("has_bad_training_data"))
+
+setGeneric("has_optimised_hyperparameters", function(object, ...) standardGeneric("has_optimised_hyperparameters"))
+
+setGeneric("fam_sample", function(x, ...) standardGeneric("fam_sample"))
+
+setGeneric("get_bootstrap_sample", function(data, ...) standardGeneric("get_bootstrap_sample"))
+
+setGeneric("get_subsample", function(data, ...) standardGeneric("get_subsample"))
+
+setGeneric("create_instance_weights", function(data, ...) standardGeneric("create_instance_weights"))
+
+
+
+# familiarModel methods --------------------------------------------------------
+setGeneric("promote_learner", function(object, ...) standardGeneric("promote_learner"))
+
+setGeneric("get_default_hyperparameters", function(object, ...) standardGeneric("get_default_hyperparameters"))
+
+setGeneric("..train", function(object, data, ...) standardGeneric("..train"))
+
+setGeneric("..train_naive", function(object, data, ...) standardGeneric("..train_naive"))
+
+setGeneric("..predict", function(object, data, ...) standardGeneric("..predict"))
+
+setGeneric("..predict_survival_probability", function(object, data, time, ...) standardGeneric("..predict_survival_probability"))
+
+setGeneric("..set_recalibration_model", function(object, data, ...) standardGeneric("..set_recalibration_model"))
+
+setGeneric("..vimp", function(object, ...) standardGeneric("..vimp"))
+
+setGeneric("get_prediction_type", function(object, ...) standardGeneric("get_prediction_type"))
+
+setGeneric("..set_calibration_info", function(object, data, ...) standardGeneric("..set_calibration_info"))
+
+setGeneric("..set_risk_stratification_thresholds", function(object, data, ...) standardGeneric("..set_risk_stratification_thresholds"))
+
+setGeneric("..set_vimp_parameters", function(object, ...) standardGeneric("..set_vimp_parameters"))
+
+setGeneric("..get_distribution_family", function(object, ...) standardGeneric("..get_distribution_family"))
+
+setGeneric("..update_outcome", function(object, data, ...) standardGeneric("..update_outcome"))
+
+setGeneric("..update_warnings", function(object, ...) standardGeneric("..update_warnings"))
+
+setGeneric("..update_errors", function(object, ...) standardGeneric("..update_errors"))
+
+setGeneric("optimise_hyperparameters", function(object, data, ...) standardGeneric("optimise_hyperparameters"))
+
+setGeneric("trim_model", function(object, ...) standardGeneric("trim_model"))
+
+setGeneric(".trim_model", function(object, ...) standardGeneric(".trim_model"))
+
+setGeneric("requires_naive_model", function(object, ...) standardGeneric("requires_naive_model"))
+
+
+
+# familiarNoveltyDetector methods ----------------------------------------------
+setGeneric("promote_detector", function(object, ...) standardGeneric("promote_detector"))
+
+
+
+# familiarVimpMethod methods ---------------------------------------------------
+setGeneric(".vimp", function(object, ...) standardGeneric(".vimp"))
+
+setGeneric("promote_vimp_method", function(object, ...) standardGeneric("promote_vimp_method"))
+
+setGeneric("prepare_vimp_object", function(data, ...) standardGeneric("prepare_vimp_object"))
+
+
+
+# familiarMetric methods -------------------------------------------------------
+setGeneric("is_higher_better", function(metric, ...) standardGeneric("is_higher_better"))
+
+setGeneric("compute_metric_score", function(metric, ...) standardGeneric("compute_metric_score"))
+
+setGeneric("compute_objective_score", function(metric, ...) standardGeneric("compute_objective_score"))
+
+setGeneric("set_metric_baseline_value", function(metric, ...) standardGeneric("set_metric_baseline_value"))
+
+
+
+# familiarCollection methods ---------------------------------------------------
 setGeneric(".set_labels", function(x, ...) standardGeneric(".set_labels"))
 
 setGeneric(".get_labels", function(x, ...) standardGeneric(".get_labels"))
@@ -166,141 +291,8 @@ setGeneric("get_risk_group_name_levels", function(x, ...) standardGeneric("get_r
 setGeneric("get_class_name_levels", function(x, ...) standardGeneric("get_class_name_levels"))
 
 
-##### Export methods #####
-# Additional methods are found in FamiliarCollectionExport.R
-setGeneric(".export_to_file", function(data, object, dir_path, ...) standardGeneric(".export_to_file"))
 
-setGeneric(".export", function(x, ...) standardGeneric(".export"))
-
-##### conversion & loading #####
-# Additional methods are documented in FamiliarObjectConversion.R
-setGeneric("load_familiar_object", function(object, ...) standardGeneric("load_familiar_object"))
-
-
-##### featureInfo specific methods ######
-setGeneric("is_available", function(object, ...) standardGeneric("is_available"))
-
-setGeneric("is_in_signature", function(object, ...) standardGeneric("is_in_signature"))
-
-setGeneric("is_in_novelty", function(object, ...) standardGeneric("is_in_novelty"))
-
-setGeneric("update_removed_status", function(object, ...) standardGeneric("update_removed_status"))
-
-setGeneric("feature_info_complete", function(object, ...) standardGeneric("feature_info_complete"))
-
-setGeneric("add_feature_info_parameters", function(object, data, ...) standardGeneric("add_feature_info_parameters"))
-
-setGeneric("apply_feature_info_parameters", function(object, data, ...) standardGeneric("apply_feature_info_parameters"))
-
-
-##### plotting methods #####
-setGeneric("plot_all", function(object, ...) standardGeneric("plot_all"))
-
-
-##### utilities #####
-setGeneric("is_empty", function(x, ...) standardGeneric("is_empty"))
-
-setGeneric("get_outcome_name", function(x, ...) standardGeneric("get_outcome_name"))
-
-setGeneric("get_outcome_class_levels", function(x, ...) standardGeneric("get_outcome_class_levels"))
-
-setGeneric("get_outcome_columns", function(x, ...) standardGeneric("get_outcome_columns"))
-
-setGeneric("get_non_feature_columns", function(x, ...) standardGeneric("get_non_feature_columns"))
-
-setGeneric("get_feature_columns", function(x, ...) standardGeneric("get_feature_columns"))
-
-setGeneric("get_n_features", function(x, ...) standardGeneric("get_n_features"))
-
-setGeneric("get_n_samples", function(x, ...) standardGeneric("get_n_samples"))
-
-setGeneric("has_feature_data", function(x, ...) standardGeneric("has_feature_data"))
-
-setGeneric("get_unique_row_names", function(x, ...) standardGeneric("get_unique_row_names"))
-
-setGeneric("get_class_probability_name", function(x, ...) standardGeneric("get_class_probability_name"))
-
-setGeneric("encode_categorical_variables", function(object, data, ...) standardGeneric("encode_categorical_variables"))
-
-setGeneric("get_placeholder_prediction_table", function(object, data, ...) standardGeneric("get_placeholder_prediction_table"))
-
-setGeneric("has_bad_training_data", function(object, data, ...) standardGeneric("has_bad_training_data"))
-
-setGeneric("has_optimised_hyperparameters", function(object, ...) standardGeneric("has_optimised_hyperparameters"))
-
-setGeneric("fam_sample", function(x, ...) standardGeneric("fam_sample"))
-
-setGeneric("get_bootstrap_sample", function(data, ...) standardGeneric("get_bootstrap_sample"))
-
-setGeneric("get_subsample", function(data, ...) standardGeneric("get_subsample"))
-
-setGeneric("create_instance_weights", function(data, ...) standardGeneric("create_instance_weights"))
-
-
-##### familiarModel learner methods #####
-setGeneric("promote_learner", function(object, ...) standardGeneric("promote_learner"))
-
-setGeneric("get_default_hyperparameters", function(object, ...) standardGeneric("get_default_hyperparameters"))
-
-setGeneric("..train", function(object, data, ...) standardGeneric("..train"))
-
-setGeneric("..train_naive", function(object, data, ...) standardGeneric("..train_naive"))
-
-setGeneric("..predict", function(object, data, ...) standardGeneric("..predict"))
-
-setGeneric("..predict_survival_probability", function(object, data, time, ...) standardGeneric("..predict_survival_probability"))
-
-setGeneric("..set_recalibration_model", function(object, data, ...) standardGeneric("..set_recalibration_model"))
-
-setGeneric("..vimp", function(object, ...) standardGeneric("..vimp"))
-
-setGeneric("get_prediction_type", function(object, ...) standardGeneric("get_prediction_type"))
-
-setGeneric("..set_calibration_info", function(object, data, ...) standardGeneric("..set_calibration_info"))
-
-setGeneric("..set_risk_stratification_thresholds", function(object, data, ...) standardGeneric("..set_risk_stratification_thresholds"))
-
-setGeneric("..set_vimp_parameters", function(object, ...) standardGeneric("..set_vimp_parameters"))
-
-setGeneric("..get_distribution_family", function(object, ...) standardGeneric("..get_distribution_family"))
-
-setGeneric("..update_outcome", function(object, data, ...) standardGeneric("..update_outcome"))
-
-setGeneric("..update_warnings", function(object, ...) standardGeneric("..update_warnings"))
-
-setGeneric("..update_errors", function(object, ...) standardGeneric("..update_errors"))
-
-setGeneric("optimise_hyperparameters", function(object, data, ...) standardGeneric("optimise_hyperparameters"))
-
-setGeneric("trim_model", function(object, ...) standardGeneric("trim_model"))
-
-setGeneric(".trim_model", function(object, ...) standardGeneric(".trim_model"))
-
-setGeneric("requires_naive_model", function(object, ...) standardGeneric("requires_naive_model"))
-
-##### familiarNoveltyDetector methods #####
-setGeneric("promote_detector", function(object, ...) standardGeneric("promote_detector"))
-
-
-#####familiarVimpMethod variable importance methods #####
-setGeneric(".vimp", function(object, ...) standardGeneric(".vimp"))
-
-setGeneric("promote_vimp_method", function(object, ...) standardGeneric("promote_vimp_method"))
-
-setGeneric("prepare_vimp_object", function(data, ...) standardGeneric("prepare_vimp_object"))
-
-
-#####familiarMetric #####
-setGeneric("is_higher_better", function(metric, ...) standardGeneric("is_higher_better"))
-
-setGeneric("compute_metric_score", function(metric, ...) standardGeneric("compute_metric_score"))
-
-setGeneric("compute_objective_score", function(metric, ...) standardGeneric("compute_objective_score"))
-
-setGeneric("set_metric_baseline_value", function(metric, ...) standardGeneric("set_metric_baseline_value"))
-
-
-#####familiarDataElement#####
+# familiarDataElement methods --------------------------------------------------
 setGeneric("extract_dispatcher", function(object, proto_data_element, ...) standardGeneric("extract_dispatcher"))
 
 setGeneric("identify_element_sets", function(x, ...) standardGeneric("identify_element_sets"))
@@ -322,8 +314,8 @@ setGeneric("..compute_data_element_estimates", function(x, ...) standardGeneric(
 setGeneric("collect", function(x, ...) standardGeneric("collect"))
 
 
-#### vimpTable -----------------------------------------------------------------
 
+# vimpTable methods ------------------------------------------------------------
 setGeneric("decode_vimp_table", function(x, ...) standardGeneric("decode_vimp_table"))
 
 setGeneric("decluster_vimp_table", function(x, ...) standardGeneric("decluster_vimp_table"))
@@ -339,3 +331,20 @@ setGeneric("remove_signature_features", function(x, ...) standardGeneric("remove
 setGeneric("update_vimp_table_to_reference", function(x, ...) standardGeneric("update_vimp_table_to_reference"))
 
 setGeneric("collect_vimp_table", function(x, ...) standardGeneric("collect_vimp_table"))
+
+
+
+# featureInfo methods ----------------------------------------------------------
+setGeneric("is_available", function(object, ...) standardGeneric("is_available"))
+
+setGeneric("is_in_signature", function(object, ...) standardGeneric("is_in_signature"))
+
+setGeneric("is_in_novelty", function(object, ...) standardGeneric("is_in_novelty"))
+
+setGeneric("update_removed_status", function(object, ...) standardGeneric("update_removed_status"))
+
+setGeneric("feature_info_complete", function(object, ...) standardGeneric("feature_info_complete"))
+
+setGeneric("add_feature_info_parameters", function(object, data, ...) standardGeneric("add_feature_info_parameters"))
+
+setGeneric("apply_feature_info_parameters", function(object, data, ...) standardGeneric("apply_feature_info_parameters"))
